( cd opt/kde/share/doc/HTML/ru/kivio ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kivio ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kugar ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kugar ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kword ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kword ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/koffice ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/koffice ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/koshell ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/koshell ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kspread ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kspread ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kchart ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kchart ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kpresenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kpresenter ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/thesaurus ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/thesaurus ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kformula ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kformula ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
